<?php 

//Creates slug from string

function woocos_slugify($text, string $divider = '-')
{
    // replace non letter or digits by divider
    $text = preg_replace('~[^\pL\d]+~u', $divider, $text);

    // transliterate
    $text = iconv('utf-8', 'us-ascii//TRANSLIT', $text);

    // remove unwanted characters
    $text = preg_replace('~[^-\w]+~', '', $text);

    // trim
    $text = trim($text, $divider);

    // remove duplicate divider
    $text = preg_replace('~-+~', $divider, $text);

    // lowercase
    $text = strtolower($text);

    if (empty($text)) {
      return 'n-a';
    }

    return $text;
}

function woocos_create_email_template($slug)
{
    $default_email_template_contents = file_get_contents( dirname(__FILE__) . '/templates/emails/default/woocos-email-template.php' );
    
    $new_email_template = dirname(__FILE__) . '/templates/emails/' . $slug . '.php';
    if (file_exists($new_email_template)) {
        return;
    } else {
        $new_email_template_file = fopen($new_email_template, "w");
        fwrite($new_email_template_file, $default_email_template_contents);
        fclose($new_email_template_file);
    }
}

function woocos_remove_email_template($slug)
{
    $email_template = dirname(__FILE__) . '/templates/emails/' . $slug . '.php';
    if(file_exists($email_template)) {
        unlink($email_template);
    }
}


function woocos_setup_email_templates()
{
    $woocos_options = json_decode(get_option('woocos_custom_order_statuses'), true);
    if (!empty($woocos_options) ) {
        foreach ( $woocos_options as $key => $option ) {
            $slug = $option['slug'];
            woocos_create_email_template($slug);
        }
    }
}

function woocos_remove_woocos_prefix()
{
    
    $woocos_options =  json_decode(get_option('woocos_custom_order_statuses'), true);

    if (!empty($woocos_options)) {
        foreach(wp_load_alloptions() as $option => $key) {
            foreach ( $woocos_options as $woocos_key => $woocos_option ) {
                if (strpos($option, 'woocommerce_' . $woocos_option['slug'] . '_settings') !== false) {
                    $option_data = get_option($option, array());
                    $option_name = str_replace('woocommerce_', 'woocommerce_woocos-', $option);
                   
                    update_option($option_name, $option_data);
                    delete_option($option);
                }
            }
        }
        foreach ( $woocos_options as $key => $option ) {
            $slug = 'woocos-' . $option['slug'];
            $args = array(
                'status'    => $slug,
                'limit'     => -1,
            );
            $orders = wc_get_orders($args);
            if ( !empty( $orders ) ) {
                foreach ( $orders as $order ) {
                    if ( $order->get_status() == $slug) {
                        $temp_slug = 'wc-' . $option['slug'];
                        $args = array(
                            'ID'            => $order->get_id(),
                            'post_status'   => $temp_slug
                        );
                        wp_update_post($args);
                    }
                }
            }
        }
    }
}

if ( in_array('print-invoices-packing-slip-labels-for-woocommerce/print-invoices-packing-slip-labels-for-woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) ) {
    add_filter('wf_pklist_alter_invoice_attachment_mail_type','wf_pklist_alter_invoice_attachments',10,4);
}
function wf_pklist_alter_invoice_attachments($attach_to_mail_for, $order_id, $email_class_id, $order)
{
    $custom_order_statuses = json_decode(get_option('woocos_custom_order_statuses'), true);
    if (!empty($custom_order_statuses)) {
        foreach ( $custom_order_statuses as $order_status ) {
            $attach_to_mail_for[] = 'woocos-' . $order_status['slug'];
        }
    }
    return $attach_to_mail_for;
}

?>